@@ -16,3 +16,11 @@ class MissingParameterException(Exception):
 
 class NotFoundException(Exception):
     pass
+
+
+class ConflictException(Exception):
+    pass
+
+
+class AfterRecordNotFoundException(Exception):
+    pass
