@@ -11,3 +11,6 @@ DATABASE_PORT = os.getenv('DATABASE_PORT', '')
 DATABASE_NAME = os.getenv('DATABASE_NAME', '')
 DATABASE_USER = os.getenv('DATABASE_USER', '')
 DATABASE_DRIVER = os.getenv('DATABASE_DRIVER', 'POSTGRES')
+
+CLOUD_SQL_CONN_NAME = os.getenv('CLOUD_SQL_CONN_NAME', '')
+ENV = os.getenv('ENV', '')
